@@ -1,19 +1,30 @@
+import importlib
 import subprocess
 import sys
+from types import ModuleType
 
 import pytest
 import typer
-import typer.core
 from typer.testing import CliRunner
 
-from docs_src.arguments.help import tutorial001 as mod
-
 runner = CliRunner()
-app = mod.app
 
 
-def test_help():
-    result = runner.invoke(app, ["--help"])
+@pytest.fixture(
+    name="mod",
+    params=[
+        pytest.param("tutorial001_py310"),
+        pytest.param("tutorial001_an_py310"),
+    ],
+)
+def get_mod(request: pytest.FixtureRequest) -> ModuleType:
+    module_name = f"docs_src.arguments.help.{request.param}"
+    mod = importlib.import_module(module_name)
+    return mod
+
+
+def test_help(mod: ModuleType):
+    result = runner.invoke(mod.app, ["--help"])
     assert result.exit_code == 0
     assert "[OPTIONS] NAME" in result.output
     assert "Arguments" in result.output
@@ -22,9 +33,9 @@ def test_help():
     assert "[required]" in result.output
 
 
-def test_help_no_rich(monkeypatch: pytest.MonkeyPatch):
+def test_help_no_rich(monkeypatch: pytest.MonkeyPatch, mod: ModuleType):
     monkeypatch.setattr(typer.core, "HAS_RICH", False)
-    result = runner.invoke(app, ["--help"])
+    result = runner.invoke(mod.app, ["--help"])
     assert result.exit_code == 0
     assert "[OPTIONS] NAME" in result.output
     assert "Arguments" in result.output
@@ -33,13 +44,13 @@ def test_help_no_rich(monkeypatch: pytest.MonkeyPatch):
     assert "[required]" in result.output
 
 
-def test_call_arg():
-    result = runner.invoke(app, ["Camila"])
+def test_call_arg(mod: ModuleType):
+    result = runner.invoke(mod.app, ["Camila"])
     assert result.exit_code == 0
     assert "Hello Camila" in result.output
 
 
-def test_script():
+def test_script(mod: ModuleType):
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__, "--help"],
         capture_output=True,
