@@ -3,7 +3,7 @@ import sys
 
 from typer.testing import CliRunner
 
-from docs_src.commands.index import tutorial004 as mod
+from docs_src.commands.index import tutorial004_py310 as mod
 
 app = mod.app
 
